aboutsummaryrefslogtreecommitdiff
path: root/engines/gob/gob.h
diff options
context:
space:
mode:
Diffstat (limited to 'engines/gob/gob.h')
-rw-r--r--engines/gob/gob.h11
1 files changed, 7 insertions, 4 deletions
diff --git a/engines/gob/gob.h b/engines/gob/gob.h
index 7291853bd4..3c79908971 100644
--- a/engines/gob/gob.h
+++ b/engines/gob/gob.h
@@ -50,7 +50,8 @@ class Parse;
class Scenery;
class GTimer;
class Util;
-class Music;
+class Adlib;
+class Infogrames;
/*
#define VAR_OFFSET(offs) (*(uint32 *)(_vm->_global->_inter_variables + (offs)))
@@ -92,14 +93,15 @@ enum {
GF_WOODRUFF = 1 << 3,
GF_CD = 1 << 4,
GF_MAC = 1 << 5,
- GF_EGA = 1 << 6
+ GF_EGA = 1 << 6,
+ GF_AMIGA = 1 << 7
};
enum {
kDebugFuncOp = 1 << 0,
kDebugDrawOp = 1 << 1,
kDebugGobOp = 1 << 2,
- kDebugMusic = 1 << 3, // CD and adlib music
+ kDebugMusic = 1 << 3, // CD, Adlib and Infogrames music
kDebugParser = 1 << 4,
kDebugGameFlow = 1 << 5,
kDebugFileIO = 1 << 6,
@@ -165,7 +167,8 @@ public:
GTimer *_gtimer;
Util *_util;
Inter *_inter;
- Music *_music;
+ Adlib *_adlib;
+ Infogrames *_infogrames;
GobEngine *_vm;
void writeVarDebug(uint32 offs, uint32 v);